==================================================
``psyclone.psyir.transformations.loop_fuse_trans``
==================================================

.. automodule:: psyclone.psyir.transformations.loop_fuse_trans

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.transformations.loop_fuse_trans


Classes
=======

- :py:class:`LoopFuseTrans`:
  Provides a generic loop-fuse transformation to two Nodes in the


.. autoclass:: LoopFuseTrans
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: LoopFuseTrans
      :parts: 1
